@@ -14,9 +14,15 @@ import sys
 import time
 from typing import Any, Optional
 from loguru import logger
+import threading
 
 class BaseEC():
+
+    _communicate_lock = threading.Lock()
+
+    send_recv_info_print = False
     
+    # logger.remove(0)
     
     def _log_init(self, ip):
         """日志格式化
@@ -24,12 +30,26 @@ class BaseEC():
         logger.remove()
         self.logger = copy.deepcopy(logger)
         # format_str = "<green>{time:YYYY-MM-DD HH:mm:ss}</green> |<yellow>Robot_ip: " + self.ip + "</yellow>|line:{line}| <level>{level} | {message}</level>"
-        format_str = "<green>{time:YYYY-MM-DD HH:mm:ss}</green> |<yellow>Robot_ip: " + ip + "</yellow>| <level>" + "{level:<8}".ljust(7) +" | {message}</level>"
+        format_str = "<green>{time:YYYY-MM-DD HH:mm:ss}</green> |<yellow>Robot_IP: " + ip + "</yellow>| <level>" + "{level:<8}".ljust(7) +" | {message}</level>"
         self.logger.add(sys.stderr, format = format_str)
         logger.add(sys.stdout)
         pass    
 
 
+    def __log_init(self, ip):
+
+        def _filter(record):
+            """存在多个stderr的输出,根据log_name进行过滤显示
+            """
+            if record["extra"].get("ip") == ip:
+                return True
+            return False
+
+        format_str = "<green>{time:YYYY-MM-DD HH:mm:ss}</green> |<yellow>Robot_IP: " + ip + "</yellow>| <level>" + "{level:<8}".ljust(7) + "|<cyan>{name}</cyan>:<cyan>{line}</cyan> - | {message}</level>"
+        logger.add(sys.stderr, format=format_str, filter=_filter, colorize=True)
+        self.logger = logger.bind(ip=ip,).opt(depth=1)
+
+
     def us_sleep(self, t):
         """ us级延时(理论上可以实现us级)
         单位: us
@@ -84,6 +104,7 @@ class BaseEC():
         # -------------------------------------------------------------------------------
         
         try:
+            self.sock_cmd.settimeout(5)
             self.sock_cmd.connect((ip,port))
             self.logger.debug(ip + " connect success")
             self.connect_state = True
@@ -125,24 +146,32 @@ class BaseEC():
         else:
             params = json.dumps(params)
         sendStr = "{{\"method\":\"{0}\",\"params\":{1},\"jsonrpc\":\"2.0\",\"id\":{2}}}".format(cmd,params,id)+"\n"
-        
+        if self.send_recv_info_print:   # print send msg
+            self.logger.info(f"Send: Func is {cmd}")
+            self.logger.info(sendStr)
         try:
-            self.sock_cmd.sendall(bytes(sendStr,"utf-8"))
-            if ret_flag == 1:               
-                ret = self.sock_cmd.recv(1024)
-                jdata = json.loads(str(ret,"utf-8"))
-                if("result" in jdata.keys()):
-                    if jdata["id"] != id :
-                        self.logger.warning("id match fail,send_id={0},recv_id={0}",id,jdata["id"])
-                    return (json.loads(jdata["result"]))
-                
-                elif("error" in jdata.keys()):
-                    self.logger.error(f"CMD: {cmd} | {jdata['error']['message']}")
-                    return (False,jdata["error"]['message'],jdata["id"])
-                else:
-                    return (False,None,None)
+            with BaseEC._communicate_lock :
+                self.sock_cmd.sendall(bytes(sendStr,"utf-8"))
+                if ret_flag == 1:               
+                    ret = self.sock_cmd.recv(1024)
+                    jdata = json.loads(str(ret,"utf-8"))
+
+                    if self.send_recv_info_print:   # print recv nsg
+                        self.logger.info(f"Recv: Func is {cmd}")
+                        self.logger.info(str(ret,"utf-8"))
+
+                    if("result" in jdata.keys()):
+                        if jdata["id"] != id :
+                            self.logger.warning("id match fail,send_id={0},recv_id={0}",id,jdata["id"])
+                        return (json.loads(jdata["result"]))
+                    
+                    elif("error" in jdata.keys()):
+                        self.logger.warning(f"CMD: {cmd} | {jdata['error']['message']}")
+                        return (False,jdata["error"]['message'],jdata["id"])
+                    else:
+                        return (False,None,None)
         except Exception as e:
-            self.logger.error(f"CMD: {cmd} | {e}")
+            self.logger.error(f"CMD: {cmd} |Exception: {e}")
             quit()
             return (False,None,None)
 
